==> xreview_0.96.zip: xreview/regist.php <==
<?php
// =======================================
// xoops module xreview
// regist.php
// =======================================
require('../../mainfile.php');
include_once './class/xreview_data.php';
include_once './class/xreview.php';
$myts =& MyTextSanitizer::getInstance();

global $xoopsUser;

// å(ե顼å)
$referer = $_SERVER['HTTP_REFERER'];
$url_length = strlen(XOOPS_URL);
if ( XOOPS_URL == substr($referer,0,strlen(XOOPS_URL)) ) {
	// ե顼URI
	$uri = substr($referer,strlen(XOOPS_URL),strlen($referer));
} else {
	//
	redirect_header( XOOPS_URL, 3, _MB_ILLEGAL_ACCESS );
	exit();
}

// ---------------------------
// ѥ᡼
// ---------------------------
sanitiza($_POST);
$comment   = $myts->stripSlashesGPC($_POST['comment']);
$nameOfUri = $myts->stripSlashesGPC($_POST['target_name']);
$point     = intval($_POST['point']);

// ---------------------------
//桼ID
// ---------------------------
$userid = $xoopsUser->getVar("uid");

// -----------------------------------
// URI
// URIξ硢xreview_uriɲ
// -----------------------------------
$sql  = "select count(*) as count from ". $xoopsDB->prefix('xreview_uri');
$sql .= " where request_uri = ".$xoopsDB->quoteString($uri);
$res = $xoopsDB->query($sql);
if($row = $xoopsDB->fetchArray($res))
{
	$count = $row['count'];
	if ($count == 0 )
	{
		// URIϿ
		$XreviewURI = new XreviewURI();
		$XreviewURI->add($uri,$nameOfUri);
	}
}


// --------------------------------
// ¸ɾȤ()å
// ǡ
// --------------------------------
$count = 0;
$select_sql  = "select count(*) as count from ".$xoopsDB->prefix('xreview_data');
$select_sql .= " where ";
$select_sql .= " request_uri=".$xoopsDB->quoteString($uri)." ";
$select_sql .= " and ";
$select_sql .= " user_id=".intval($userid);
$select_res = $xoopsDB->query($select_sql);
$row = $xoopsDB->fetchArray($select_res);
if ($row['count'] == 0)
{
	// -------------
	// ɲ
	// -------------
	if($point != "") {
		$XreviewReview = new XreviewReview();
		$XreviewReview->add($uri,$userid,$comment,$point);
		$post_message = _MB_REVIEW_POSTED;
	} else {
		$post_message = _MB_REVIEW_FAILURE_POSTED;
	}
} else {
	if($point == "") {
		// -------------
		// ǡ
		// -------------
		$XreviewReview = new XreviewReviewByUriUserid($uri,$userid);
		$XreviewReview->delete();
		$post_message = _MB_REVIEW_DELETE_POSTED;
	} else {
		// -------------
		// ǡ
		// -------------
		$XreviewReview = new XreviewReviewByUriUserid($uri,$userid);
		$XreviewReview->update($comment,$point);
		$post_message = _MB_REVIEW_UPDATE_POSTED;
	}
}

// 쥯
redirect_header( $_SERVER['HTTP_REFERER'], 3, $post_message );

?>

==> xreview_0.97.zip: xreview/regist.php <==
<?php
// =======================================
// xoops module xreview
// regist.php
// =======================================
require('../../mainfile.php');
include_once './class/xreview_data.php';
include_once './class/xreview.php';
$myts =& MyTextSanitizer::getInstance();

global $xoopsUser;

// ---------------------------
// 
// ---------------------------
sanitiza($_POST);
sanitiza($_SESSION);

//󥿥åȤå
$token = $myts->stripSlashesGPC($_POST['token']);
$ticket = $_SESSION['ticket'];
if( $_SESSION[$ticket] == $token )
{
	//å󥯥ꥢ
	unset($_SESSION[$ticket]);
	unset($_SESSION['ticket']);
} else {
	//
	redirect_header( XOOPS_URL, 3, _MB_ILLEGAL_ACCESS );
	exit();
}

// ---------------------------
// ѥ᡼
// ---------------------------
$hasErr = false;
$err_message = array();
$comment   = $myts->stripSlashesGPC($_POST['comment']);
if( !checkComment($comment) ) {
	$hasErr = true;
	$err_message[] = _MB_ERR_REVIEW_COMMENT;
}
$nameOfUri = $myts->stripSlashesGPC($_POST['target_name']);
if( !checkTitle($nameOfUri) ) {
	$hasErr = true;
	$err_message[] = _MB_ERR_REVIEW_TITLE;
}
$point     = intval($_POST['point']);
if( !checkPoint($point) ) {
	$hasErr = true;
	$err_message[] = _MB_ERR_REVIEW_POINT;
}
$uri = $myts->stripSlashesGPC($_SESSION['target_uri']);
if( !checkURI($uri) ) {
	$hasErr = true;
	$err_message[] = _MB_ERR_REVIEW_URI;
}

if( $hasErr ) {
	//顼
	redirect_header( XOOPS_URL.$uri, 3, _MB_ERR_HEAD."<br>".join("<br>",$err_message) );
	exit();
}

// ---------------------------
//桼ID
// ---------------------------
$userid = intval($xoopsUser->getVar("uid"));

// -----------------------------------
// URI
// URIξ硢xreview_uriɲ
// -----------------------------------
$sql  = "select count(*) as count from ". $xoopsDB->prefix('xreview_uri');
$sql .= " where request_uri = ".$xoopsDB->quoteString($uri);
$res = $xoopsDB->query($sql);
if($row = $xoopsDB->fetchArray($res))
{
	$count = $row['count'];
	if ($count == 0 )
	{
		// URIϿ
		$XreviewURI = new XreviewURI();
		$res = $XreviewURI->add($uri,$nameOfUri);
		if( !$res ) {
			//顼
			redirect_header( XOOPS_URL.$uri, 3, _MB_ERR_DATABASE );
			exit();
		}
	}
}


// --------------------------------
// ¸ɾȤ()å
// ǡ
// --------------------------------
$count = 0;
$select_sql  = "select count(*) as count from ".$xoopsDB->prefix('xreview_data');
$select_sql .= " where ";
$select_sql .= " request_uri=".$xoopsDB->quoteString($uri)." ";
$select_sql .= " and ";
$select_sql .= " user_id=".intval($userid);
$select_res = $xoopsDB->query($select_sql);
$row = $xoopsDB->fetchArray($select_res);
if ($row['count'] == 0)
{
	// -------------
	// ɲ
	// -------------
	if($point != "") {
		$XreviewReview = new XreviewReview();
		$res = $XreviewReview->add($uri,$userid,$comment,$point);
		if( !$res ) {
			//顼
			redirect_header( XOOPS_URL.$uri, 3, _MB_ERR_DATABASE );
			exit();
		}
		$post_message = _MB_REVIEW_POSTED;
	} else {
		$post_message = _MB_REVIEW_FAILURE_POSTED;
	}
} else {
	if($point == "") {
		// -------------
		// ǡ
		// -------------
		$XreviewReview = new XreviewReviewByUriUserid($uri,$userid);
		$res = $XreviewReview->delete();
		if( !$res ) {
			//顼
			redirect_header( XOOPS_URL.$uri, 3, _MB_ERR_DATABASE );
			exit();
		}
		$post_message = _MB_REVIEW_DELETE_POSTED;
	} else {
		// -------------
		// ǡ
		// -------------
		$XreviewReview = new XreviewReviewByUriUserid($uri,$userid);
		$res = $XreviewReview->update($comment,$point);
		if( !$res ) {
			//顼
			redirect_header( XOOPS_URL.$uri, 3, _MB_ERR_DATABASE );
			exit();
		}
		$post_message = _MB_REVIEW_UPDATE_POSTED;
	}
}

// 쥯
redirect_header( $_SERVER['HTTP_REFERER'], 3, $post_message );

?>
